==> webkit2gtk_2.17.91.orig.tar.xz: webkitgtk-2.17.91/Source/WebCore/html/canvas/WebGPUDepthStencilDescriptor.h <==
/*
 * Copyright (C) 2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WEBGPU)

#include "WebGPUEnums.h"
#include "WebGPUObject.h"

#include <wtf/Vector.h>

namespace WebCore {

class GPUDepthStencilDescriptor;

class WebGPUDepthStencilDescriptor : public WebGPUObject {
public:
    virtual ~WebGPUDepthStencilDescriptor();
    static Ref<WebGPUDepthStencilDescriptor> create();

    bool depthWriteEnabled() const;
    void setDepthWriteEnabled(bool);

    using CompareFunction = WebGPUCompareFunction;
    CompareFunction depthCompareFunction() const;
    void setDepthCompareFunction(CompareFunction);

    GPUDepthStencilDescriptor* depthStencilDescriptor() { return m_depthStencilDescriptor.get(); }

private:
    WebGPUDepthStencilDescriptor();

    WebGPUCompareFunction m_depthCompareFunction;
    RefPtr<GPUDepthStencilDescriptor> m_depthStencilDescriptor;
};

} // namespace WebCore

#endif

==> webkit2gtk_2.22.0.orig.tar.xz: webkitgtk-2.22.0/Source/WebCore/html/canvas/WebGPUDepthStencilDescriptor.h <==
/*
 * Copyright (C) 2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WEBGPU)

#include "GPUDepthStencilDescriptor.h"
#include "WebGPUEnums.h"
#include <wtf/Ref.h>
#include <wtf/RefCounted.h>

namespace WebCore {

class WebGPUDepthStencilDescriptor : public RefCounted<WebGPUDepthStencilDescriptor> {
public:
    static Ref<WebGPUDepthStencilDescriptor> create();

    bool depthWriteEnabled() const;
    void setDepthWriteEnabled(bool);

    using CompareFunction = WebGPUCompareFunction;
    CompareFunction depthCompareFunction() const;
    void setDepthCompareFunction(CompareFunction);

    GPUDepthStencilDescriptor& descriptor() { return m_descriptor; }

private:
    WebGPUDepthStencilDescriptor() = default;

    // FIXME: The default value of "Always" is defined both here and in the
    // GPUDepthStencilDescriptor class's implementation. Might be better to not
    // store the compare function separately here, translate it instead, and then
    // there would be no need for a default value here.

    WebGPUCompareFunction m_depthCompareFunction { WebGPUCompareFunction::Always };
    GPUDepthStencilDescriptor m_descriptor;
};

} // namespace WebCore

#endif
